# nflxprofile

Python package exposing the `nflxprofile` format as a Python class.

## Install

```
pip install nflxprofile
```

## Usage

```python
from nflxprofile import nflxprofile_pb2

profile = nflxprofile_pb2.Profile()
```
